@@ -10,10 +10,15 @@ create_table_pages_pdf <- function(rs, cntnt, lpg_rows) {
   content_blank_row <- cntnt$blank_row
   
   pgby_var <- NA
-  if (!is.null(rs$page_by))
+  pgby_cnt <- 0
+  pgby_fmt <- NULL
+  if (!is.null(rs$page_by)) {
     pgby_var <- rs$page_by$var
-  else if (!is.null(ts$page_by))
+    pgby_fmt <- rs$page_by$format
+  } else if (!is.null(ts$page_by)) {
     pgby_var <- ts$page_by$var
+    pgby_fmt <- ts$page_by$format
+  }
   
   
   if (all(ts$show_cols == "none") & length(ts$col_defs) == 0) {
@@ -57,11 +62,17 @@ create_table_pages_pdf <- function(rs, cntnt, lpg_rows) {
       
     } else {
       
-      dat$..page_by <-  dat[[pgby_var]] 
+      if (!is.null(pgby_fmt))
+        dat$..page_by <-  fapply(dat[[pgby_var]], pgby_fmt)
+      else 
+        dat$..page_by <- dat[[pgby_var]]
     }
     
-    if (is.unsorted(dat[[pgby_var]], strictly = FALSE))
-      message("Page by variable not sorted.")
+    pgby_cnt <- get_pgby_cnt(dat$..page_by)
+    
+    # Commenting out for now
+    # if (is.unsorted(dat[[pgby_var]], strictly = FALSE))
+    #   message("Page by variable not sorted.")
   }
   
   # Deal with invisible columns
@@ -178,7 +189,8 @@ create_table_pages_pdf <- function(rs, cntnt, lpg_rows) {
   
   
   # Offsets are needed to calculate splits and page breaks
-  content_offset <- get_content_offsets_pdf(rs, ts, tmp_pi, content_blank_row)
+  content_offset <- get_content_offsets_pdf(rs, ts, tmp_pi, 
+                                            content_blank_row, pgby_cnt)
   
   # Need to do something with widths
   # split rows
@@ -476,7 +488,7 @@ get_page_footnotes_pdf <- function(rs, spec, spec_width, lpg_rows, ystart,
 #' Needed to calculate page breaks accurately.
 #' @return A vector of upper and lower offsets
 #' @noRd
-get_content_offsets_pdf <- function(rs, ts, pi, content_blank_row) {
+get_content_offsets_pdf <- function(rs, ts, pi, content_blank_row, pgby_cnt = NULL) {
   
   ret <- c(upper = 0, lower = 0, blank_upper = 0, blank_lower = 0)
   cnt <- c(upper = 0, lower = 0, blank_upper = 0, blank_lower = 0)
@@ -507,9 +519,9 @@ get_content_offsets_pdf <- function(rs, ts, pi, content_blank_row) {
   # Get page by if it exists
   pgb <- list(lines = 0, points = 0)
   if (!is.null(ts$page_by))
-    pgb <- get_page_by_pdf(ts$page_by, wdth, NULL, rs, pi$table_align)
+    pgb <- get_page_by_pdf(ts$page_by, wdth, NULL, rs, pi$table_align, pgby_cnt = pgby_cnt)
   else if (!is.null(rs$page_by))
-    pgb <- get_page_by_pdf(rs$page_by, wdth, NULL, rs, pi$table_align)
+    pgb <- get_page_by_pdf(rs$page_by, wdth, NULL, rs, pi$table_align, pgby_cnt = pgby_cnt)
   
   
   #print(length(pgb))
