@@ -10,12 +10,16 @@ create_table_pages_rtf <- function(rs, cntnt, lpg_rows) {
   content_blank_row <- cntnt$blank_row
   
   pgby_var <- NA
-  if (!is.null(rs$page_by))
+  pgby_cnt <- 0
+  pgby_fmt <- NULL
+  if (!is.null(rs$page_by)) {
     pgby_var <- rs$page_by$var
-  else if (!is.null(ts$page_by))
+    pgby_fmt <- rs$page_by$format
+  } else if (!is.null(ts$page_by)) {
     pgby_var <- ts$page_by$var
-  
-  
+    pgby_fmt <- ts$page_by$format
+  }
+
   if (all(ts$show_cols == "none") & length(ts$col_defs) == 0) {
     
     stop("ERROR: At least one column must be defined if show_cols = \"none\".")
@@ -57,11 +61,17 @@ create_table_pages_rtf <- function(rs, cntnt, lpg_rows) {
       
     } else {
       
-      dat$..page_by <-  dat[[pgby_var]] 
+      if (!is.null(pgby_fmt))
+        dat$..page_by <-  fapply(dat[[pgby_var]], pgby_fmt)
+      else 
+        dat$..page_by <-  dat[[pgby_var]]
     }
     
-    if (is.unsorted(dat[[pgby_var]], strictly = FALSE))
-      message("Page by variable not sorted.")
+    pgby_cnt <- get_pgby_cnt(dat$..page_by)
+    
+    # Commenting out for now
+    # if (is.unsorted(dat[[pgby_var]], strictly = FALSE))
+    #   message("Page by variable not sorted.")
   }
   
   # Deal with invisible columns
@@ -124,7 +134,7 @@ create_table_pages_rtf <- function(rs, cntnt, lpg_rows) {
   fdat <- fdata(cdat)
   # print("fdata:")
   # print(fdat)
-  
+
   # Prep data for blank lines, indents, and stub columns
   fdat <- prep_data(fdat, ts, rs$char_width, rs$missing) # OK
   # print("prep_data")
@@ -175,9 +185,9 @@ create_table_pages_rtf <- function(rs, cntnt, lpg_rows) {
   
 
   # Offsets are needed to calculate splits and page breaks
-  content_offset <- get_content_offsets_rtf(rs, ts, tmp_pi, content_blank_row)
+  content_offset <- get_content_offsets_rtf(rs, ts, tmp_pi, 
+                                            content_blank_row, pgby_cnt)
   
-
   # split rows
   splits <- get_splits_text(fdat, widths_uom, rs$body_line_count, 
                             lpg_rows, content_offset$lines, ts, TRUE)  
@@ -485,7 +495,7 @@ get_page_footnotes_rtf <- function(rs, spec, spec_width, lpg_rows, row_count,
 #' Needed to calculate page breaks accurately.
 #' @return A vector of upper and lower offsets
 #' @noRd
-get_content_offsets_rtf <- function(rs, ts, pi, content_blank_row) {
+get_content_offsets_rtf <- function(rs, ts, pi, content_blank_row, pgby_cnt = NULL) {
   
   ret <- c(upper = 0, lower = 0, blank_upper = 0, blank_lower = 0)
   cnt <- c(upper = 0, lower = 0, blank_upper = 0, blank_lower = 0)
@@ -516,9 +526,9 @@ get_content_offsets_rtf <- function(rs, ts, pi, content_blank_row) {
   # Get page by if it exists
   pgb <- list(lines = 0, twips = 0)
   if (!is.null(ts$page_by))
-    pgb <- get_page_by_rtf(ts$page_by, wdth, NULL, rs, pi$table_align)
+    pgb <- get_page_by_rtf(ts$page_by, wdth, NULL, rs, pi$table_align, pgby_cnt)
   else if (!is.null(rs$page_by))
-    pgb <- get_page_by_rtf(rs$page_by, wdth, NULL, rs, pi$table_align)
+    pgb <- get_page_by_rtf(rs$page_by, wdth, NULL, rs, pi$table_align, pgby_cnt)
 
   
   #print(length(pgb))
