@@ -1193,4 +1193,28 @@ test_that("pdf37: Stub indent.", {
   
 })
 
-
+test_that("pdf38: Title and footnotes Columns work as expected.", {
+  
+  fp <- file.path(base_path, "pdf/test38.pdf")
+  
+  tbl <- create_table(iris[1:15, ]) %>%
+    define(Species, visible = FALSE)
+  
+  ttl <- c("Title1", "Title2", "Title3")
+  
+  rpt <- create_report(fp, output_type = "PDF", 
+                       orientation = "portrait") %>%
+    add_content(tbl) %>%
+    page_header("left", "right") %>%
+    page_footer("left", "", "right") %>%
+    titles(ttl,
+           blank_row = "below", columns =  3, align = "center",
+           borders = "none") %>%
+    footnotes("Here is a footnote", "And another", columns = 2, borders = "top")
+  
+  
+  res <- write_report(rpt)
+  
+  expect_equal(file.exists(fp), TRUE)
+  
+})
